@@ -15,5 +15,11 @@ def node_is_subclass(cls, subclass_name):
             for inf in base_cls.infered():
                 if inf.qname() == subclass_name:
                     return True
+                if node_is_subclass(inf, subclass_name):
+                    # check up the hierachy in case we are a subclass of
+                    # a subclass of a subclass ...
+                    return True
         except InferenceError:
-            pass
\ No newline at end of file
+            pass
+
+    return False
\ No newline at end of file
